import random

class LocalFunnyLoader:
    jokes = [
        "This is where it all begins...",
        "This commit is a lie",
        "I'll explain when you're older!",
        "Batman! (this commit has no parents)",
        "The same thing we do every night, Pinky - try to take over the world!",
        "Version control is awful",
        "Lock S-foils in attack position",
        "Commit committed",
        "Just have the project 90% done and call it \"Initial import\"",
        "Whatever.",
        "A journey of a thousand miles begins with a single step",
        "I don't believe it.",
        "Future self, please forgive me and don't hit me with the baseball bat again!",
        "just shoot me",
        "I have no idea what I'm doing here.",
        "lolwhat?",
        "that coulda been bad",
        "It works! Just ship it! :boat:"
    ]

    def get_message(self):
        return random.choice(self.jokes)


class LocalMessageLoader:
    messages = [
        "Initial commit",
        "First commit",
        "added readme",
        "1st commit",
        "first commit, added files",
        "init"
    ]

    def get_message(self):
        return random.choice(self.messages)


class LocalHackLoader:
    messages = [
        "will be eventually fixed in the future, isn't that what we all tell ourselves",
        "did it to unblock business, just like everything else",
        "will fix this.. someday",
        "adding this commit now, so that there are jobs left for people in the future",
        "the important thing is - business is unblocked",
        "message to anyone who sees this in the future: THIS IS SPARTA",
        "for the love of God and all things holy - please fix this",
        "someone - someday - will recall stories of how they fixed this hack",
        "I am going to look back at this someday and scream at the dev who wrote it only to realize it was me",
        "I like to live dangerously"
    ]

    def get_message(self):
        return random.choice(self.messages)



import click
from message_loaders import LocalMessageLoader
from message_loaders import LocalFunnyLoader
from message_loaders import LocalHackLoader
from signatures import get_signature
import git
import os

@click.command()
@click.option('--first', '-f', is_flag=True, help='Interesting first commit message')
@click.option('--hack', '-h', is_flag=True, help='Adds a joke that the commit is a hack')
@click.option('--signature', '-s', help='Adds an ascii signature to the commit')
@click.option('--message', '-m', help="Commit message to be appended with")
def main(first, hack, signature, message):
    """Generates funny commit message for you"""
    
    if first:
        loader = LocalMessageLoader()
    elif hack:
        loader = LocalHackLoader()
    else:
        loader = LocalFunnyLoader()

    cm = loader.get_message()

    signatures = {
        ""
    }

    if message:
        cm = """{}
===
{}""".format(message, cm)

    if signature:
        cm = """{}
===
{}""".format(cm, get_signature(signature))
        
    repo = git.Repo(os.getcwd())
    repo.git.commit('-am', cm)
                    
    # click.echo(cm)
